@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2011 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2011 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2015 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2015 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -26,6 +26,14 @@
 
 #ifdef HAVE_LIBESMTP
 
+
+#define ESMTPTO         32            /* 'To' buffer size max */
+#define ESMTPFROM       32            /* 'From' buffer size max */
+#define ESMTPSERVER     32            /* SMTP server size max */
+#define MAX_EMAILSIZE   15360          /* Largest e-mail that can be sent */
+
+const char *esmtp_cb (void **, int *, void *);
+int Sagan_ESMTP_Thread( _SaganEvent * );
 int fixlf(_SaganConfig *, char *, char *);
 
 #endif
