@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2012 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2012 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2015 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2015 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -37,18 +37,25 @@
 #include "version.h"
 
 #include "sagan.h"
+#include "sagan-defs.h"
+#include "sagan-key.h"
+#include "sagan-stats.h"
 
-void key_handler( _SaganConfig *config )
+struct _SaganConfig *config;
+
+void key_handler( void )
 {
 
-  while(1) {
+    while(1)
+        {
 
-	int key; 
+            int key;
 
-	key=getchar();
-		   if ( key != 0 ) {
-		   sagan_statistics(config);
-		   }
+            key=getchar();
+            if ( key != 0 )
+                {
+                    Sagan_Statistics();
+                }
 
-	}
+        }
 }
